@@ -5,20 +5,23 @@
   *  by Jason Munro 6/23/02
   *
   **/
+define('SM_PATH','../../');
 
-require_once('shared_functions.php');
-chdir ('..');
-require_once('../src/validate.php');
-require_once('../functions/page_header.php');
+/* Calender plugin required files. */
+require_once(SM_PATH . 'plugins/calendar/shared_functions.php');
+
+/* SquirrelMail required files. */
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/page_header.php');
+require_once(SM_PATH . 'functions/html.php');
 
 extract($_POST);
 
-if (!isset($color[12])) $color[12] = '';
 displayPageHeader($color, 'None');
 main_menu($color);
 $indent = "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
-if (isset($cal_action)) {
-     if ($cal_action == 'Calendars') {
+if (isset($submit)) {
+     if ($submit == 'Calendars') {
         if (isset($add_action) && $add_action == 'Add') {
             if (!empty($new_cal) && !preg_match("/^(\s){1,}$/", $new_cal)) {
                 if (isset($public) && $public == 'yes') {
@@ -65,11 +68,11 @@ if (isset($cal_action)) {
                " calendars use the \"Users\" button.") . "</td></tr><tr><td align=left>";
         print "<br>" . _("<b>Public</b> calendars are available to all SquirrelMail users\n".
               " in addition to their private personal calendar.") . "</td></tr></table><br>\n".
-              "<form action=\"admin_options.php\" method=post>\n".
               "<table align=center width=\"80%\" bgcolor=\"$color[9]\">\n".
               "<tr bgcolor=\"$color[4]\"><td align=center>\n";
          if (!empty($shared_list)) {
-            print "<br><table align=center width=\"100%\" bgcolor=\"$color[12]\">\n".
+            print "<form action=\"admin_options.php\" method=post>\n".
+                  "<br><table align=center width=\"100%\" bgcolor=\"$color[12]\">\n".
                   "<tr bgcolor=\"$color[10]\"><td align=center></td><td align=center>\n".
                   "<b>" . _("Shared calendars") . "</b>\n".
                   "</td></tr>\n";
@@ -82,7 +85,8 @@ if (isset($cal_action)) {
             }
          }
          else {
-             print "<table align=center width=\"100%\" bgcolor=\"$color[12]\">\n".
+             print "<form action=\"admin_options.php\" method=post>\n".
+                   "<table align=center width=\"100%\" bgcolor=\"$color[12]\">\n".
                    "<tr bgcolor=\"$color[10]\"><td align=center>\n".
                    "<b>Shared calendars</b>\n".
                    "</td></tr><tr><td align=center>\n".
@@ -115,25 +119,21 @@ if (isset($cal_action)) {
 
          print "<br><table width=\"80%\" align=center><tr><td>\n".
                "<b>" . _("Delete selected calendar") . "</b></td></tr><tr><td align=center>\n".
-               "<input type=submit value=\"" . _("Delete") . "\">\n".
-               "<input type=hidden name=del_action value=\"Delete\">\n".
-               "<input type=hidden name=cal_action value=\"Calendars\">\n".
-               "</td></tr></table></form>\n".
-               "<form action=\"admin_options.php\" method=post>\n".
-               "<table width=\"80%\" align=center><tr><td><b>" . _("Add a new calender") . "</b></td></tr><tr><td align=center>\n".
+               "<input type=submit name=del_action value=\"" . _("Delete") . "\">\n".
+               "</tr></td><tr><td><b>" . _("Add a new calender") . "</b></td></tr><tr><td align=center>\n".
                _("Name") . ":&nbsp;<input type=text name=new_cal size=\"50\">\n".
                "</td></tr><tr><td align=center>\n".
-               "<input type=hidden name=cal_action value=\"Calendars\">\n".
-               "<input type=hidden name=add_action value=\"Add\">\n".
+               "<input type=hidden name=submit value=\"Calendars\">\n".
                "<input type=checkbox name=public value=\"yes\">\n".
                "&nbsp;&nbsp;" . _("make <b>PUBLIC</b> (read/write for all users)") . "\n".
-               "</tr></td><tr><td align=center><input type=submit value=\"" . _("Add") . "\">\n".
+               "</tr></td><tr><td align=center><input type=submit name=add_action value=\"" . _("Add") . "\">\n".
                "</td></tr></table><br><br></form>\n";
               
      }
 
-     elseif ($cal_action == 'Users') {
+     elseif ($submit == 'Users') {
          $cal_list = read_calendar_list($data_dir, 'shared');
+         print "<form action=\"admin_options.php\" method=post>\n";
          print "<table align=center width=\"80%\"><tr><td>\n";
          print _("Here you can manage user access to shared calendars.\n"
              . " First create the shared calendars with the \"Calendars\" button.\n"
@@ -158,9 +158,8 @@ if (isset($cal_action)) {
             $userdata = get_user_codes($data_dir);
             $usercount = count($userdata);
             for ($j=0;$j<$usercount;$j++) {
-                if ($Name == $userdata[$j]['name']) 
-                //if (preg_match("/^$Name$/", $userdata[$j]['name'])) 
-                {
+                if ($Name == $userdata[$j]['name']) {
+                //if (preg_match("/^$Name$/", $userdata[$j]['name'])) {
                    $userdata[$j]['code'] = $val;
                 }
             }
@@ -216,9 +215,8 @@ if (isset($cal_action)) {
              }
              print "</select></td></tr>\n".
                    "</table><br>\n".
-                   "<center><input type=submit value=\"" . _("Submit") . "\">\n".
-                   "<center><input type=hidden name=commit_modify value=\"Submit\">\n".
-                   "</center><input type=hidden name=cal_action value=\"Users\">\n".
+                   "<center><input type=submit name=commit_modify value=\"" . _("Submit") . "\">\n".
+                   "</center><input type=hidden name=submit value=\"Users\">\n".
                    "</center><input type=hidden name=\"Name\" value=\"$user_select\">\n".
                    "</form>\n";
              exit();
@@ -229,18 +227,13 @@ if (isset($cal_action)) {
          if (!isset($userdata)) {
             $userdata = get_user_codes($data_dir);
          }
-         print "<form action=\"admin_options.php\" method=post>\n";
          print "<br><table align=center><tr><td align=center>\n".
                "<b>Add user to shared calendar setup</b>\n".
                "</td></tr><tr><td align=center>\n".
                "<input type=text name=user_input>\n".
                "</td></tr><tr><td align=center>\n".
-               "<input type=submit value=\"" . _("Add") . "\">\n".
-               "<input type=hidden name=add_user value=\"Add\">\n".
-               "<input type=hidden name=cal_action value=\"Users\">\n".
+               "<input type=submit name=add_user value=\"" . _("Add") . "\"\n".
                "</td></tr></table>\n".
-               "</form>\n".
-               "<form name=\"modUserForm\" action=\"admin_options.php\" method=post>\n".
                "<br><center><table  bgcolor=\"$color[9]\"><tr><td>\n".
                "<center><b>Shared Calendar Access Table</b></td></tr><tr><td>\n".
                "<table  bgcolor=\"$color[4]\">\n".
@@ -282,12 +275,11 @@ if (isset($cal_action)) {
          }
          }
          print "</tr></table></td></tr></table></center>\n".       
-               "<input type=hidden name=cal_action value=\"Users\">\n".
+               "<input type=hidden name=submit value=\"Users\">\n".
                "<br><table align=center><tr><td>\n".
-               "<input type=hidden name=mod_user value=\"\">\n".
-               "<input type=submit value=\"" . _("Modify") . "\" onClick=\"document.modUserForm.mod_user.value='Modify'\">$indent\n".
+               "<input type=submit name=mod_user value=\"" . _("Modify") . "\">$indent\n".
                "</td><td><b>" . _("Modify the currently selected user's calendar access") . "</b>\n".
-               "</td></tr><tr><td><input type=submit value=\"" . _("Delete") . "\" onClick=\"document.modUserForm.mod_user.value='Delete'\">$indent\n". 
+               "</td></tr><tr><td><input type=submit name=mod_user value=\"" . _("Delete") . "\">$indent\n".
                "</td><td><b>" . _("Remove the currently selected user from shared calendar access") . "</b>\n".
                "</td></tr></table><br></form>";
     }        
