@@ -19,7 +19,7 @@ function approve_cal_admin() {
     should be entered into the following array.
 ***********************************************************************/
 
-    $admins = array("paul@patiencehosting.net", "aragorn@patiencehosting.net", "test2");
+    $admins = array("user1@mydomain.com", "user2", "user3");
 
 /**********************************************************************   
  *    Then those users can go to Options->Shared Calendar
@@ -35,7 +35,7 @@ function approve_cal_admin() {
     }
     foreach ($admins as $admin) {
         if (isset($username)) {
-            if ($debug) echo "username=$username admin=$admin<br>admin == username ?? --> ". (strtolower($username)==strtolower($admin))."<br>";
+            if ($debug) echo "username=$username admin=$admin<br>";
             if (strtolower($username) == strtolower($admin)) {
                 $approved = true;
             }
@@ -72,7 +72,7 @@ function cal_admin_block() {
 
 function calendar_version() {
 
-    return '0.5.7';
+    return '1.0.1';
 
 }
 
