@@ -1,8 +1,8 @@
 <?PHP
 
 function main_menu($color) {
-    if (!isset($color[12])) $color[12] = '';
     print "<br><br><center>\n".
+        "<form action=\"admin_options.php\" method=post>\n".
         "<table width=\"80%\" bgcolor=\"$color[9]\"><tr><td align=center>\n".
         "<b>" . _("Shared Calendar Setup") . "</b></td></tr><tr><td>\n".
         "<table width=\"100%\" bgcolor=\"$color[9]\" cellpadding=3>\n".
@@ -13,17 +13,12 @@ function main_menu($color) {
         _("Here you can give users rights to read and/or\n".
         "write to the available shared access calendars.\n").
         "</td></tr><tr><td align=center>\n".
-        "<form action=\"admin_options.php\" method=post>\n".
-        "<input type=submit value=\"" . _("Calendars") . "\">\n".
-        "<input type=hidden name=\"cal_action\" value=\"Calendars\">\n".
-        "</form>".
+        "<input type=submit name=\"submit\" value=\"" . _("Calendars") . "\">\n".
         "</td><td align=center>\n".
-        "<form action=\"admin_options.php\" method=post>\n".
-        "<input type=submit value=\"" . _("Users") . "\">\n".
-        "<input type=hidden name=\"cal_action\" value=\"Users\">\n".
-        "</form>".
+        "<input type=submit name=\"submit\" value=\"" . _("Users") . "\">\n".
         "</td></tr></table>".
         "</td></tr></table>\n".
+        "</form>\n".
         "</center>\n";
 }
 
